@@ -1,14 +1,14 @@
 #define STATUS "-stable"		/* stable branch */
 #if 0
 #define STATUS ""			/* release */
-#define STATUS "-current"		/* just after a release */
 #define STATUS "-beta"			/* just before a release */
+#define STATUS "-current"		/* just after a release */
 #endif
 
 const char ostype[] = "OpenBSD";
-const char osrelease[] = "6.9";
+const char osrelease[] = "7.0";
 const char osversion[] = "RDROOT.MP#1";
 const char sccs[] =
-    "    @(#)OpenBSD 6.9" STATUS " (RDROOT.MP) #1: Mon May 24 21:23:07 JST 2021\n";
+    "    @(#)OpenBSD 7.0" STATUS " (RDROOT.MP) #1: Mon Nov  1 12:41:55 JST 2021\n";
 const char version[512] =
-    "OpenBSD 6.9" STATUS " (RDROOT.MP) #1: Mon May 24 21:23:07 JST 2021\n    root@nimbus12.localnet:/opt/fi/6.9/sys/arch/amd64/compile/RDROOT.MP\n";
+    "OpenBSD 7.0" STATUS " (RDROOT.MP) #1: Mon Nov  1 12:41:55 JST 2021\n    root@nimbus12.localnet:/opt/fi/7.0/sys/arch/amd64/compile/RDROOT.MP\n";
